@@ -33,7 +33,6 @@ from abc import ABCMeta
 from collections import MutableMapping
 
 from ..helpers import getLogger
-import collections
 
 # Gets the instance of the logger.
 logSys = getLogger(__name__)
@@ -85,7 +84,7 @@ class CallingMap(MutableMapping):
 
 	def __getitem__(self, key):
 		value = self.data[key]
-		if isinstance(value, collections.Callable):
+		if callable(value):
 			return value()
 		else:
 			return value
@@ -146,7 +145,7 @@ class ActionBase(object, metaclass=ABCMeta):
 			"unban",
 			)
 		for method in required:
-			if not isinstance(getattr(C, method, None), collections.Callable):
+			if not callable(getattr(C, method, None)):
 				return False
 		return True
 
@@ -254,7 +253,7 @@ class CommandAction(ActionBase):
 		return dict(
 			(key, getattr(self, key))
 			for key in dir(self)
-			if not key.startswith("_") and not isinstance(getattr(self, key), collections.Callable))
+			if not key.startswith("_") and not callable(getattr(self, key)))
 
 	@property
 	def actionstart(self):
