@@ -174,6 +174,14 @@ class FilterSystemd(JournalFilter): # pragma: systemd no cover
 		v = Filter.uni_decode(x, self.getLogEncoding())
 		return v
 
+	##
+	# Get journal reader
+	#
+	# @return journal reader
+
+	def getJournalReader(self):
+		return self.__journal
+
 	##
 	# Format journal log entry into syslog style
 	#
